@@ -482,13 +482,15 @@ static void cell_data_func (GtkTreeViewColumn *tree_column,
   if (meta->size == 0) {
     g_object_set(G_OBJECT(cell),
 		 "foreground", GNOMAD_DIRECTORY_FOLDER_ENTRY_COLOR, 
-		 "weight", "bold",
-		 "underline", TRUE,
+		 "weight", GNOMAD_DIRECTORY_FOLDER_ENTRY_WEIGHT,
+		 "style", GNOMAD_DIRECTORY_FOLDER_ENTRY_STYLE,
+		 "underline", PANGO_UNDERLINE_SINGLE,
 		 NULL);
   } else {
     g_object_set(G_OBJECT(cell),
 		 "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
-		 "weight", NULL,
+		 "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
+		 "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 		 "underline", FALSE,
 		 NULL);
   }
@@ -510,7 +512,8 @@ static GtkWidget *create_listview(GtkListStore *liststore)
   textrenderer = gtk_cell_renderer_text_new ();
   g_object_set(G_OBJECT(textrenderer),
 	       "foreground", GNOMAD_DIRECTORY_FILE_ENTRY_COLOR, 
-	       "weight", NULL,
+	       "weight", GNOMAD_DIRECTORY_FILE_ENTRY_WEIGHT,
+	       "style", GNOMAD_DIRECTORY_FILE_ENTRY_STYLE,
 	       "underline", FALSE,
 	       NULL);
 
