@@ -25,7 +25,7 @@ Boston, MA 02111-1307, USA.
 #include "mp3file.h"
 #include "id3read.h"
 #include "wmaread.h"
-#include "wavfile.h"
+#include "riffile.h"
 #include "xfer.h"
 #ifdef HAVE_TAGLIB
 #include "tagfile.h"
@@ -341,6 +341,8 @@ static GList *get_directory_listing(gchar* base_path, gboolean anyfile)
 	  /* Only display valid files */
           if (g_ascii_strcasecmp(tmp+1,"mp3") &&
               g_ascii_strcasecmp(tmp+1,"wav") &&
+              g_ascii_strcasecmp(tmp+1,"avi") &&
+              g_ascii_strcasecmp(tmp+1,"wmv") &&
               g_ascii_strcasecmp(tmp+1,"wma")
 #ifdef HAVE_LIBMTP
 	      // Additional music codecs supported by libmtp
@@ -514,6 +516,9 @@ static GList *get_metadata_for_dirlist(GList *inlist,
            get_tag_for_file(meta);
 #endif
 	}
+	if (!strcmp(meta->codec,"AVI")) {
+           get_tag_for_avifile(meta);
+        }
 	// Implement getting track metadata for the other libmtp
 	// supported filetypes here...
 	if (!strcmp(meta->codec,"MP2")) {
@@ -822,8 +827,18 @@ gint delete_files(GList *filelist)
     /* g_print("Deleting: %s\n", meta->path); */
     tmp = filename_fromutf8(meta->path);
 
-    /* Skip past current and parent directory if selected */
-    if (!strcmp(tmp, ".") || !strcmp(tmp, "..")) {
+    /*
+     * Skip past current and parent directory if selected.
+     * Be sure to avoid also /foo/bar/.. and /foo/bar/.
+     */
+    if (
+	(strlen(tmp) >= 1 && !strcmp(tmp+strlen(tmp)-1, "."))
+	||
+	(strlen(tmp) >= 2 && !strcmp(tmp+strlen(tmp)-2, ".."))
+	) {
+      g_print("Skipping deletion of: %s\n", meta->path);
+      g_free(tmp);
+      tmplist = tmplist->next;
       continue;
     }
     
