@@ -65,7 +65,9 @@ gboolean is_directory(gchar *dir);
 void change_directory(gchar *dir);
 gint delete_dir_contents(gchar *dir);
 gint delete_files(GList *filelist);
-gboolean clone_and_strip_id3(const gchar *const source, const gchar * const dest);
+gboolean clone_and_strip_tag(const gchar *const source, 
+			     const gchar * const dest, 
+			     const gchar * const codec);
 gint get_prefsfile_fd(gboolean write);
 void close_prefsfile(void);
 void rewrite_prefsfile(gchar *prefs);
