@@ -632,6 +632,45 @@ static GtkListStore *create_jbdataliststore(void)
   return jbdataliststore;
 }
 
+static gint compare_lengths(gchar * length1, gchar * length2)
+{
+  gint retval;
+  if (!length2)
+    retval = (length1 != NULL);
+  else if (!length1)
+    retval = -1;
+  else
+  {
+    gchar * sep;
+    gchar ** cmp1;
+    gchar ** cmp2;
+    gint min1, sec1, min2, sec2;
+    cmp1 = g_strsplit(length1, ":", 2);
+    cmp2 = g_strsplit(length2, ":", 2);
+    min1 = g_ascii_strtoll(cmp1[0], 0, 10);
+    sec1 = g_ascii_strtoll(cmp1[1], 0, 10);
+    min2 = g_ascii_strtoll(cmp2[0], 0, 10);
+    sec2 = g_ascii_strtoll(cmp2[1], 0, 10);
+    if (min1 < min2)
+      retval = -1;
+    else if (min1 > min2)
+      retval = 1;
+    else
+    {
+      if (sec1 < sec2)
+        retval = -1;
+      else if (sec1 > sec2)
+        retval = 1;
+      else
+        retval = 0;
+    }
+    g_strfreev(cmp1);
+    g_strfreev(cmp2);
+  }
+  return retval;
+}
+
+
 /* This intercompare function sorts the directories on top of
  * the files in the harddisk list view. (It is not used at all
  * for the jukebox view.)
@@ -709,6 +748,17 @@ static gint hdlist_compare_func (GtkTreeModel *model,
         retval = sort_iter_compare_func(model, a, b, GINT_TO_POINTER(sort_column_id));
       }
       break;
+      case TRACKLIST_LENGTH_COLUMN:
+      {
+           gchar *text1;
+           gchar *text2;
+           gtk_tree_model_get(model, a, sort_column_id, &text1, -1);
+           gtk_tree_model_get(model, b, sort_column_id, &text2, -1);
+           retval = compare_lengths(text1, text2);
+           g_free(text1);
+           g_free(text2);
+      }
+      break;
       default:
       {
         /* Dynamically decide how to handle different text types */
@@ -870,6 +920,13 @@ void view_and_sort_list_store(listtype_t listtype)
 					 TRACKLIST_ARTIST_COLUMN,
 					 GTK_SORT_ASCENDING);
   } else if (listtype == JB_LIST) {
+    for (i = TRACKLIST_ARTIST_COLUMN; i < TRACKLIST_ARTIST_COLUMN + TRACKLIST_N_COLUMNS; i++) {
+      gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(transfer_widgets.jbliststore),
+				      i,
+				      hdlist_compare_func,
+				      NULL,
+				      NULL);
+    }
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(transfer_widgets.jbliststore),
 					 TRACKLIST_ARTIST_COLUMN,
 					 GTK_SORT_ASCENDING);
