@@ -176,7 +176,7 @@ parse_extended_content_description(guchar *data, guint size, metadata_t *meta)
 	meta->trackno = desc_value;
       }
       // This is only used unless something better is present.
-      if (!strcmp(desc_name, "WM/Track") || !strcmp(desc_name, "Track") || meta->trackno == 0) {
+      if (!strcmp(desc_name, "WM/Track") || !strcmp(desc_name, "Track")) {
 	meta->trackno = desc_value;
       }
     } else {
